// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PLASMA5SUPPORT_VERSION_H
#define PLASMA5SUPPORT_VERSION_H

#define PLASMA5SUPPORT_VERSION_STRING "6.7.2"
#define PLASMA5SUPPORT_VERSION_MAJOR 6
#define PLASMA5SUPPORT_VERSION_MINOR 7
#define PLASMA5SUPPORT_VERSION_PATCH 2
#define PLASMA5SUPPORT_VERSION ((6<<16)|(7<<8)|(2))

#endif
